@@ -10,6 +10,7 @@ from .utils.files import save_vocab
 from .utils.files import load_counts
 from .utils.files import save_counts
 from .utils.data import load_dataset
+from .utils.data import load_dataset_words
 from .utils.metrix import similarity
 from .utils.metrix import spearman
 from .utils.metrix import pearson
@@ -17,7 +18,7 @@ from .utils.metrix import rmse
 from .utils.metrix import hmean
 from .utils.metrix import energy
 from .utils.stats import steiger_test_pval
-from .core.reducer import _reduce_dense as reduce_dense
-from .core.reducer import _reduce_sparse as reduce_sparse
+from .core.reducer import reduce_dense
+from .core.reducer import reduce_sparse
 from .core.converter import convert_to_txt
 from .core.evaluator import evaluate_word_similarity
